@@ -27,12 +27,12 @@ import java.util.logging.Logger;
 
 import jakarta.faces.context.ExternalContext;
 
-import org.apache.myfaces.shared.util.ClassUtils;
+import org.apache.myfaces.util.lang.ClassUtils;
 import org.xml.sax.EntityResolver;
 import org.xml.sax.InputSource;
 
 /**
- * SAX EntityResolver to provide JSF-specific resources (DTDs) for well-known identifiers.
+ * SAX EntityResolver to provide Faces-specific resources (DTDs) for well-known identifiers.
  *
  * @author Manfred Geiler (latest modification by $Author$)
  * @author Thomas Spiegl
@@ -60,6 +60,7 @@ public class FacesConfigEntityResolver implements EntityResolver
     {
     }
 
+    @Override
     public InputSource resolveEntity(String publicId,
                                      String systemId)
         throws IOException
