@@ -25,25 +25,27 @@ import java.net.URL;
 import java.util.HashMap;
 import java.util.Map;
 
-import javax.el.ELException;
-import javax.faces.FacesException;
-import javax.faces.application.Resource;
-import javax.faces.application.ResourceHandler;
-import javax.faces.context.FacesContext;
-import javax.faces.view.facelets.BehaviorConfig;
-import javax.faces.view.facelets.BehaviorHandler;
-import javax.faces.view.facelets.ComponentConfig;
-import javax.faces.view.facelets.ComponentHandler;
-import javax.faces.view.facelets.ConverterConfig;
-import javax.faces.view.facelets.ConverterHandler;
-import javax.faces.view.facelets.FaceletException;
-import javax.faces.view.facelets.FaceletHandler;
-import javax.faces.view.facelets.Tag;
-import javax.faces.view.facelets.TagConfig;
-import javax.faces.view.facelets.TagHandler;
-import javax.faces.view.facelets.ValidatorConfig;
-import javax.faces.view.facelets.ValidatorHandler;
-import org.apache.myfaces.shared.config.MyfacesConfig;
+import jakarta.el.ELException;
+import jakarta.faces.FacesException;
+import jakarta.faces.application.Resource;
+import jakarta.faces.application.ResourceHandler;
+import jakarta.faces.context.FacesContext;
+import jakarta.faces.view.facelets.BehaviorConfig;
+import jakarta.faces.view.facelets.BehaviorHandler;
+import jakarta.faces.view.facelets.ComponentConfig;
+import jakarta.faces.view.facelets.ComponentHandler;
+import jakarta.faces.view.facelets.ConverterConfig;
+import jakarta.faces.view.facelets.ConverterHandler;
+import jakarta.faces.view.facelets.FaceletException;
+import jakarta.faces.view.facelets.FaceletHandler;
+import jakarta.faces.view.facelets.Tag;
+import jakarta.faces.view.facelets.TagConfig;
+import jakarta.faces.view.facelets.TagHandler;
+import jakarta.faces.view.facelets.ValidatorConfig;
+import jakarta.faces.view.facelets.ValidatorHandler;
+
+import org.apache.myfaces.config.webparameters.MyfacesConfig;
+import org.apache.myfaces.view.facelets.LocationAwareFacesException;
 import org.apache.myfaces.view.facelets.tag.composite.CompositeComponentResourceTagHandler;
 import org.apache.myfaces.view.facelets.tag.composite.CompositeResouceWrapper;
 
@@ -60,31 +62,40 @@ public abstract class AbstractTagLibrary implements TagLibrary
     private final Map<String, Method> _functions;
 
     private final String _namespace;
-    private final String _aliasNamespace;
+    private final String _jcpNamespace;
+    private final String _sunNamespace;
     private Boolean _strictJsf2FaceletsCompatibility;
 
-    public AbstractTagLibrary(String namespace, String aliasNamespace)
-    {
-        _namespace = namespace;
-        _aliasNamespace = aliasNamespace;
-        _factories = new HashMap<String, TagHandlerFactory>();
-        _functions = new HashMap<String, Method>();
-    }
-    
     public AbstractTagLibrary(String namespace)
     {
-        this(namespace,null);
+        this(namespace, null, null);
     }
     
-
+    public AbstractTagLibrary(String namespace, String jcpNamespace)
+    {
+        this(namespace, jcpNamespace, null);
+    }
+    
+    public AbstractTagLibrary(String namespace, String jcpNamespace, String sunNamespace)
+    {
+        _namespace = namespace;
+        _jcpNamespace = jcpNamespace;
+        _sunNamespace = sunNamespace;
+        _factories = new HashMap<>();
+        _functions = new HashMap<>();
+    }
+ 
     /*
      * (non-Javadoc)
      * 
      * See org.apache.myfaces.view.facelets.tag.TagLibrary#containsNamespace(java.lang.String)
      */
+    @Override
     public boolean containsNamespace(String ns)
     {
-        return _namespace.equals(ns) || (_aliasNamespace != null && _aliasNamespace.equals(ns));
+        return _namespace.equals(ns)
+                || (_jcpNamespace != null && _jcpNamespace.equals(ns))
+                || (_sunNamespace != null && _sunNamespace.equals(ns));
     }
 
     /*
@@ -92,6 +103,7 @@ public abstract class AbstractTagLibrary implements TagLibrary
      * 
      * See org.apache.myfaces.view.facelets.tag.TagLibrary#containsTagHandler(java.lang.String, java.lang.String)
      */
+    @Override
     public boolean containsTagHandler(String ns, String localName)
     {
         return containsNamespace(ns) && _factories.containsKey(localName);
@@ -103,6 +115,7 @@ public abstract class AbstractTagLibrary implements TagLibrary
      * See org.apache.myfaces.view.facelets.tag.TagLibrary#createTagHandler(java.lang.String, java.lang.String,
      * org.apache.myfaces.view.facelets.tag.TagConfig)
      */
+    @Override
     public TagHandler createTagHandler(String ns, String localName, TagConfig tag) throws FacesException
     {
         if (containsNamespace(ns))
@@ -122,6 +135,7 @@ public abstract class AbstractTagLibrary implements TagLibrary
      * 
      * See org.apache.myfaces.view.facelets.tag.TagLibrary#containsFunction(java.lang.String, java.lang.String)
      */
+    @Override
     public boolean containsFunction(String ns, String name)
     {
         return containsNamespace(ns) && _functions.containsKey(name);
@@ -132,6 +146,7 @@ public abstract class AbstractTagLibrary implements TagLibrary
      * 
      * See org.apache.myfaces.view.facelets.tag.TagLibrary#createFunction(java.lang.String, java.lang.String)
      */
+    @Override
     public Method createFunction(String ns, String name)
     {
         return containsNamespace(ns) ? _functions.get(name) : null;
@@ -146,7 +161,7 @@ public abstract class AbstractTagLibrary implements TagLibrary
      * Add a ComponentHandler with the specified componentType and rendererType, aliased by the tag name.
      * 
      * See ComponentHandler
-     * See javax.faces.application.Application#createComponent(java.lang.String)
+     * See jakarta.faces.application.Application#createComponent(java.lang.String)
      * @param name
      *            name to use, "foo" would be &lt;my:foo /&gt;
      * @param componentType
@@ -188,8 +203,8 @@ public abstract class AbstractTagLibrary implements TagLibrary
     /**
      * Add a ConvertHandler for the specified converterId
      * 
-     * See javax.faces.view.facelets.ConverterHandler
-     * See javax.faces.application.Application#createConverter(java.lang.String)
+     * See jakarta.faces.view.facelets.ConverterHandler
+     * See jakarta.faces.application.Application#createConverter(java.lang.String)
      * @param name
      *            name to use, "foo" would be &lt;my:foo /&gt;
      * @param converterId
@@ -203,9 +218,9 @@ public abstract class AbstractTagLibrary implements TagLibrary
     /**
      * Add a ConvertHandler for the specified converterId of a TagHandler type
      * 
-     * See javax.faces.view.facelets.ConverterHandler
-     * See javax.faces.view.facelets.ConverterConfig
-     * See javax.faces.application.Application#createConverter(java.lang.String)
+     * See jakarta.faces.view.facelets.ConverterHandler
+     * See jakarta.faces.view.facelets.ConverterConfig
+     * See jakarta.faces.application.Application#createConverter(java.lang.String)
      * 
      * @param name
      *            name to use, "foo" would be &lt;my:foo /&gt;
@@ -222,8 +237,8 @@ public abstract class AbstractTagLibrary implements TagLibrary
     /**
      * Add a ValidateHandler for the specified validatorId
      * 
-     * See javax.faces.view.facelets.ValidatorHandler
-     * See javax.faces.application.Application#createValidator(java.lang.String)
+     * See jakarta.faces.view.facelets.ValidatorHandler
+     * See jakarta.faces.application.Application#createValidator(java.lang.String)
      * 
      * @param name
      *            name to use, "foo" would be &lt;my:foo /&gt;
@@ -238,9 +253,9 @@ public abstract class AbstractTagLibrary implements TagLibrary
     /**
      * Add a ValidateHandler for the specified validatorId
      * 
-     * See javax.faces.view.facelets.ValidatorHandler
-     * See javax.faces.view.facelets.ValidatorConfig
-     * See javax.faces.application.Application#createValidator(java.lang.String)
+     * See jakarta.faces.view.facelets.ValidatorHandler
+     * See jakarta.faces.view.facelets.ValidatorConfig
+     * See jakarta.faces.application.Application#createValidator(java.lang.String)
      * @param name
      *            name to use, "foo" would be &lt;my:foo /&gt;
      * @param validatorId
@@ -280,8 +295,7 @@ public abstract class AbstractTagLibrary implements TagLibrary
     {
         if (_strictJsf2FaceletsCompatibility == null)
         {
-            MyfacesConfig config = MyfacesConfig.getCurrentInstance(
-                    FacesContext.getCurrentInstance().getExternalContext());
+            MyfacesConfig config = MyfacesConfig.getCurrentInstance(FacesContext.getCurrentInstance());
 
             _strictJsf2FaceletsCompatibility = config.isStrictJsf2FaceletsCompatibility();
         }
@@ -298,7 +312,7 @@ public abstract class AbstractTagLibrary implements TagLibrary
     /**
      * Add a Method to be used as a Function at Compilation.
      * 
-     * See javax.el.FunctionMapper
+     * See jakarta.el.FunctionMapper
      * 
      * @param name
      *            (suffix) of function name
@@ -334,7 +348,6 @@ public abstract class AbstractTagLibrary implements TagLibrary
 
     private static class ValidatorConfigWrapper implements ValidatorConfig
     {
-
         private final TagConfig parent;
         private final String validatorId;
 
@@ -344,21 +357,25 @@ public abstract class AbstractTagLibrary implements TagLibrary
             this.validatorId = validatorId;
         }
 
+        @Override
         public String getValidatorId()
         {
             return this.validatorId;
         }
 
+        @Override
         public FaceletHandler getNextHandler()
         {
             return this.parent.getNextHandler();
         }
 
+        @Override
         public Tag getTag()
         {
             return this.parent.getTag();
         }
 
+        @Override
         public String getTagId()
         {
             return this.parent.getTagId();
@@ -376,21 +393,25 @@ public abstract class AbstractTagLibrary implements TagLibrary
             this.converterId = converterId;
         }
 
+        @Override
         public String getConverterId()
         {
             return this.converterId;
         }
 
+        @Override
         public FaceletHandler getNextHandler()
         {
             return this.parent.getNextHandler();
         }
 
+        @Override
         public Tag getTag()
         {
             return this.parent.getTag();
         }
 
+        @Override
         public String getTagId()
         {
             return this.parent.getTagId();
@@ -408,11 +429,12 @@ public abstract class AbstractTagLibrary implements TagLibrary
             this.handlerType = handlerType;
         }
 
+        @Override
         public TagHandler createHandler(TagConfig cfg) throws FacesException, ELException
         {
             try
             {
-                return handlerType.getConstructor(CONSTRUCTOR_SIG).newInstance(new Object[] { cfg });
+                return handlerType.getConstructor(CONSTRUCTOR_SIG).newInstance(cfg);
             }
             catch (InvocationTargetException ite)
             {
@@ -427,23 +449,22 @@ public abstract class AbstractTagLibrary implements TagLibrary
                 }
                 else
                 {
-                    throw new FacesException("Error Instantiating: " + handlerType.getName(), t);
+                    throw new LocationAwareFacesException("Error Instantiating: " + handlerType.getName(), t,
+                            cfg.getTag().getLocation());
                 }
             }
             catch (Exception e)
             {
-                throw new FacesException("Error Instantiating: " + handlerType.getName(), e);
+                throw new LocationAwareFacesException("Error Instantiating: " + handlerType.getName(), e,
+                        cfg.getTag().getLocation());
             }
         }
     }
 
     private static class ComponentConfigWrapper implements ComponentConfig
     {
-
         protected final TagConfig parent;
-
         protected final String componentType;
-
         protected final String rendererType;
 
         public ComponentConfigWrapper(TagConfig parent, String componentType, String rendererType)
@@ -453,26 +474,31 @@ public abstract class AbstractTagLibrary implements TagLibrary
             this.rendererType = rendererType;
         }
 
+        @Override
         public String getComponentType()
         {
             return this.componentType;
         }
 
+        @Override
         public String getRendererType()
         {
             return this.rendererType;
         }
 
+        @Override
         public FaceletHandler getNextHandler()
         {
             return this.parent.getNextHandler();
         }
 
+        @Override
         public Tag getTag()
         {
             return this.parent.getTag();
         }
 
+        @Override
         public String getTagId()
         {
             return this.parent.getTagId();
@@ -488,6 +514,7 @@ public abstract class AbstractTagLibrary implements TagLibrary
             this.location = location;
         }
 
+        @Override
         public TagHandler createHandler(TagConfig cfg) throws FacesException, ELException
         {
             return new UserTagHandler(cfg, this.location);
@@ -503,6 +530,7 @@ public abstract class AbstractTagLibrary implements TagLibrary
             this.location = location;
         }
 
+        @Override
         public TagHandler createHandler(TagConfig cfg) throws FacesException, ELException
         {
             return new LegacyUserTagHandler(cfg, this.location);
@@ -511,9 +539,7 @@ public abstract class AbstractTagLibrary implements TagLibrary
 
     private static class ComponentHandlerFactory implements TagHandlerFactory
     {
-
         protected final String componentType;
-
         protected final String renderType;
 
         /**
@@ -525,6 +551,7 @@ public abstract class AbstractTagLibrary implements TagLibrary
             this.renderType = renderType;
         }
 
+        @Override
         public TagHandler createHandler(TagConfig cfg) throws FacesException, ELException
         {
             ComponentConfig ccfg = new ComponentConfigWrapper(cfg, this.componentType, this.renderType);
@@ -534,15 +561,11 @@ public abstract class AbstractTagLibrary implements TagLibrary
 
     private static class UserComponentHandlerFactory implements TagHandlerFactory
     {
-
         private final static Class<?>[] CONS_SIG = new Class[] { ComponentConfig.class };
 
         protected final String componentType;
-
         protected final String renderType;
-
         protected final Class<? extends TagHandler> type;
-
         protected final Constructor<? extends TagHandler> constructor;
 
         /**
@@ -563,12 +586,13 @@ public abstract class AbstractTagLibrary implements TagLibrary
             }
         }
 
+        @Override
         public TagHandler createHandler(TagConfig cfg) throws FacesException, ELException
         {
             try
             {
                 ComponentConfig ccfg = new ComponentConfigWrapper(cfg, componentType, renderType);
-                return constructor.newInstance(new Object[] { ccfg });
+                return constructor.newInstance(ccfg);
             }
             catch (InvocationTargetException e)
             {
@@ -583,7 +607,6 @@ public abstract class AbstractTagLibrary implements TagLibrary
 
     private static class ValidatorHandlerFactory implements TagHandlerFactory
     {
-
         protected final String validatorId;
 
         public ValidatorHandlerFactory(String validatorId)
@@ -591,6 +614,7 @@ public abstract class AbstractTagLibrary implements TagLibrary
             this.validatorId = validatorId;
         }
 
+        @Override
         public TagHandler createHandler(TagConfig cfg) throws FacesException, ELException
         {
             return new ValidatorHandler(new ValidatorConfigWrapper(cfg, this.validatorId));
@@ -599,7 +623,6 @@ public abstract class AbstractTagLibrary implements TagLibrary
 
     private static class ConverterHandlerFactory implements TagHandlerFactory
     {
-
         protected final String converterId;
 
         public ConverterHandlerFactory(String converterId)
@@ -607,6 +630,7 @@ public abstract class AbstractTagLibrary implements TagLibrary
             this.converterId = converterId;
         }
 
+        @Override
         public TagHandler createHandler(TagConfig cfg) throws FacesException, ELException
         {
             return new ConverterHandler(new ConverterConfigWrapper(cfg, this.converterId));
@@ -618,9 +642,7 @@ public abstract class AbstractTagLibrary implements TagLibrary
         private final static Class<?>[] CONS_SIG = new Class[] { ConverterConfig.class };
 
         protected final String converterId;
-
         protected final Class<? extends TagHandler> type;
-
         protected final Constructor<? extends TagHandler> constructor;
 
         public UserConverterHandlerFactory(String converterId, Class<? extends TagHandler> type)
@@ -637,12 +659,13 @@ public abstract class AbstractTagLibrary implements TagLibrary
             }
         }
 
+        @Override
         public TagHandler createHandler(TagConfig cfg) throws FacesException, ELException
         {
             try
             {
                 ConverterConfig ccfg = new ConverterConfigWrapper(cfg, converterId);
-                return constructor.newInstance(new Object[] { ccfg });
+                return constructor.newInstance(ccfg);
             }
             catch (InvocationTargetException e)
             {
@@ -660,9 +683,7 @@ public abstract class AbstractTagLibrary implements TagLibrary
         private final static Class<?>[] CONS_SIG = new Class[] { ValidatorConfig.class };
 
         protected final String validatorId;
-
         protected final Class<? extends TagHandler> type;
-
         protected final Constructor<? extends TagHandler> constructor;
 
         public UserValidatorHandlerFactory(String validatorId, Class<? extends TagHandler> type)
@@ -679,12 +700,13 @@ public abstract class AbstractTagLibrary implements TagLibrary
             }
         }
 
+        @Override
         public TagHandler createHandler(TagConfig cfg) throws FacesException, ELException
         {
             try
             {
                 ValidatorConfig ccfg = new ValidatorConfigWrapper(cfg, validatorId);
-                return constructor.newInstance(new Object[] { ccfg });
+                return constructor.newInstance(ccfg);
             }
             catch (InvocationTargetException e)
             {
@@ -700,7 +722,6 @@ public abstract class AbstractTagLibrary implements TagLibrary
     private static class BehaviorConfigWrapper implements BehaviorConfig
     {
         protected final TagConfig parent;
-
         protected final String behaviorId;
 
         public BehaviorConfigWrapper(TagConfig parent, String behaviorId)
@@ -709,21 +730,25 @@ public abstract class AbstractTagLibrary implements TagLibrary
             this.behaviorId = behaviorId;
         }
 
+        @Override
         public FaceletHandler getNextHandler()
         {
             return this.parent.getNextHandler();
         }
 
+        @Override
         public Tag getTag()
         {
             return this.parent.getTag();
         }
 
+        @Override
         public String getTagId()
         {
             return this.parent.getTagId();
         }
 
+        @Override
         public String getBehaviorId()
         {
             return this.behaviorId;
@@ -740,6 +765,7 @@ public abstract class AbstractTagLibrary implements TagLibrary
             this.behaviorId = behaviorId;
         }
 
+        @Override
         public TagHandler createHandler(TagConfig cfg) throws FacesException, ELException
         {
             BehaviorConfig bcfg = new BehaviorConfigWrapper(cfg,this.behaviorId);
@@ -752,9 +778,7 @@ public abstract class AbstractTagLibrary implements TagLibrary
         private final static Class<?>[] CONS_SIG = new Class[] { BehaviorConfig.class };
 
         protected final String behaviorId;
-
         protected final Class<? extends TagHandler> type;
-
         protected final Constructor<? extends TagHandler> constructor;
 
         public UserBehaviorHandlerFactory(String behaviorId, Class<? extends TagHandler> type)
@@ -771,12 +795,13 @@ public abstract class AbstractTagLibrary implements TagLibrary
             }
         }
 
+        @Override
         public TagHandler createHandler(TagConfig cfg) throws FacesException, ELException
         {
             try
             {
                 BehaviorConfig bcfg = new BehaviorConfigWrapper(cfg,this.behaviorId);
-                return constructor.newInstance(new Object[] { bcfg });
+                return constructor.newInstance(bcfg);
             }
             catch (InvocationTargetException e)
             {
@@ -798,6 +823,7 @@ public abstract class AbstractTagLibrary implements TagLibrary
             this.resourceId = resourceId;
         }
 
+        @Override
         public TagHandler createHandler(TagConfig cfg) throws FacesException, ELException
         {
             FacesContext facesContext = FacesContext.getCurrentInstance();
@@ -808,7 +834,7 @@ public abstract class AbstractTagLibrary implements TagLibrary
                 Resource compositeComponentResource
                         = new CompositeResouceWrapper(compositeComponentResourceWrapped);
                 ComponentConfig componentConfig = new ComponentConfigWrapper(cfg,
-                        "javax.faces.NamingContainer", null);
+                        "jakarta.faces.NamingContainer", null);
 
                 return new CompositeComponentResourceTagHandler(componentConfig,
                                                                 compositeComponentResource);
