@@ -18,6 +18,9 @@
  */
 package jakarta.faces.component;
 
+import org.apache.myfaces.core.api.shared.lang.ClassUtils;
+import org.apache.myfaces.core.api.shared.ComponentUtils;
+import org.apache.myfaces.core.api.shared.lang.LocaleUtils;
 import java.io.IOException;
 import java.lang.reflect.Method;
 import java.util.ArrayList;
@@ -52,7 +55,6 @@ import jakarta.faces.event.PhaseEvent;
 import jakarta.faces.event.PhaseId;
 import jakarta.faces.event.PhaseListener;
 import jakarta.faces.event.PostConstructViewMapEvent;
-import jakarta.faces.event.PreDestroyViewMapEvent;
 import jakarta.faces.event.SystemEvent;
 import jakarta.faces.event.SystemEventListener;
 import jakarta.faces.lifecycle.Lifecycle;
@@ -65,9 +67,10 @@ import org.apache.myfaces.buildtools.maven2.plugin.builder.annotation.JSFCompone
 import org.apache.myfaces.buildtools.maven2.plugin.builder.annotation.JSFJspProperty;
 import org.apache.myfaces.buildtools.maven2.plugin.builder.annotation.JSFProperty;
 import org.apache.myfaces.buildtools.maven2.plugin.builder.annotation.JSFWebConfigParam;
+import org.apache.myfaces.core.api.shared.lang.Assert;
 
 /**
- * Creates a JSF View, which is a container that holds all of the components that are part of the view.
+ * Creates a Faces View, which is a container that holds all of the components that are part of the view.
  * <p>
  * Unless otherwise specified, all attributes accept static values or EL expressions.
  * </p>
@@ -76,7 +79,7 @@ import org.apache.myfaces.buildtools.maven2.plugin.builder.annotation.JSFWebConf
  * Specification</a> for further details.
  * </p>
  */
-@JSFComponent(name = "f:view", bodyContent = "JSP", tagClass = "org.apache.myfaces.taglib.core.ViewTag")
+@JSFComponent(name = "f:view")
 @JSFJspProperty(name = "binding", returnType = "java.lang.String", tagExcluded = true)
 public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
 {
@@ -98,8 +101,6 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
     private static final PhaseProcessor APPLY_REQUEST_VALUES_PROCESSOR = new ApplyRequestValuesPhaseProcessor();
     private static final PhaseProcessor PROCESS_VALIDATORS_PROCESSOR = new ProcessValidatorPhaseProcessor();
     private static final PhaseProcessor UPDATE_MODEL_PROCESSOR = new UpdateModelPhaseProcessor();
-
-    private static final VisitCallback RESET_VALUES_CALLBACK = new ResetValuesCallback();
     
     /**
      * Class that is used to create the view scope map. This strategy
@@ -117,7 +118,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         try
         {
             VIEW_SCOPE_PROXY_MAP_CLASS
-                    = _ClassUtils.classForName("org.apache.myfaces.view.ViewScopeProxyMap");
+                    = ClassUtils.classForName("org.apache.myfaces.view.ViewScopeProxyMap");
         }
         catch (Exception e)
         {
@@ -127,11 +128,11 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         try
         {
             REQUEST_VIEW_CONTEXT_CLASS
-                    = _ClassUtils.classForName("org.apache.myfaces.context.RequestViewContext");
+                    = ClassUtils.classForName("org.apache.myfaces.context.RequestViewContext");
             REQUEST_VIEW_CONTEXT_GET_INSTANCE = REQUEST_VIEW_CONTEXT_CLASS.getMethod("getCurrentInstance",
-                    new Class[] { FacesContext.class });
+                    FacesContext.class);
             REQUEST_VIEW_CONTEXT_SET_RENDER_TARGET = REQUEST_VIEW_CONTEXT_CLASS.getMethod("setRenderTarget",
-                    new Class[] { String.class, boolean.class, UIComponent.class });
+                    String.class, boolean.class, UIComponent.class);
         }
         catch (Exception e)
         {
@@ -139,12 +140,6 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         }
     }
 
-    /**
-     * The counter which will ensure a unique component id for every component instance in the tree that doesn't have an
-     * id attribute set.
-     */
-    //private long _uniqueIdCounter = 0;
-
     // todo: is it right to save the state of _events and _phaseListeners?
     private List<FacesEvent> _events;
 
@@ -177,6 +172,8 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
     private transient boolean _resourceDependencyUniqueId;
     private transient Map<String,Object> _attributesMap;
     
+    private Doctype doctype;
+    
     /**
      * Construct an instance of the UIViewRoot.
      */
@@ -224,6 +221,18 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
             // https://issues.apache.org/jira/browse/MYFACES-2775
             componentId = createUniqueId(context, null);
             componentResource.setId(componentId);
+            List<UIComponent> children = componentResource.getChildren();
+
+            /*
+             * MYFACES-4631
+             * Duplicate ID Exception can occur if children also aren't assigned unique IDs
+             * See https://github.com/primefaces-extensions/primefaces-extensions/issues/517
+             */
+            for(UIComponent child : children) {
+                String childId =  createUniqueId(context, null); 
+                child.setId(childId);
+                // TODO - Should we nest down further? 
+            }
         }
         
         // This var helps to handle the case when we try to add a component that already is
@@ -330,7 +339,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
                 componentResources.add(componentResource);
             }
 
-            // this is required to make dynamic resource loading possible since JSF 2.3
+            // this is required to make dynamic resource loading possible since Faces 2.3
             if (context.getPartialViewContext().isAjaxRequest())
             {
                 boolean isBuildingInitialState
@@ -365,10 +374,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
      */
     public void addPhaseListener(PhaseListener phaseListener)
     {
-        if (phaseListener == null)
-        {
-            throw new NullPointerException("phaseListener");
-        }
+        Assert.notNull(phaseListener, "phaseListener");
         
         getStateHelper().add(PropertyKeys.phaseListeners, phaseListener);
     }
@@ -431,11 +437,12 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         if (loops == maxLoops && events.hasMoreEvents())
         {
             // broadcast reach maxLoops - probably a infinitive recursion:
-            boolean production = getFacesContext().isProjectStage(ProjectStage.Production);
-            Level level = production ? Level.FINE : Level.WARNING;
+            Level level = getFacesContext().isProjectStage(ProjectStage.Production)
+                    ? Level.FINE
+                    : Level.WARNING;
             if (_getLogger().isLoggable(level))
             {
-                List<String> name = new ArrayList<String>(events.getAnyPhase().size() + events.getOnPhase().size());
+                List<String> name = new ArrayList<>(events.getAnyPhase().size() + events.getOnPhase().size());
                 for (FacesEvent facesEvent : events.getAnyPhase())
                 {
                     String clientId = facesEvent.getComponent().getClientId(getFacesContext());
@@ -469,12 +476,13 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
      * 
      * @since 2.0
      */
+    @Override
     public String createUniqueId(FacesContext context, String seed)
     {
 
         // Generate an identifier for a component. The identifier will be prefixed with
         // UNIQUE_ID_PREFIX, and will be unique within this UIViewRoot.
-        if(seed==null)
+        if(seed == null)
         {
             if (isResourceDependencyUniqueId())
             {
@@ -482,15 +490,14 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
                     PropertyKeys.resourceDependencyUniqueIdCounter);
                 uniqueIdCounter = (uniqueIdCounter == null) ? 0 : uniqueIdCounter;
                 getStateHelper().put(PropertyKeys.resourceDependencyUniqueIdCounter, (uniqueIdCounter+1));
-                if (uniqueIdCounter >= _ComponentUtils.UNIQUE_COMPONENT_RD_IDS_SIZE)
+                if (uniqueIdCounter >= ComponentUtils.UNIQUE_COMPONENT_RD_IDS_SIZE)
                 {
                     StringBuilder bld = _getSharedStringBuilder(context);
-                    return bld.append(UNIQUE_ID_PREFIX).append(
-                        _ComponentUtils.RD_ID_PREFIX).append(uniqueIdCounter).toString();
+                    return bld.append(UNIQUE_ID_PREFIX).append(ComponentUtils.RD_ID_PREFIX).append(uniqueIdCounter).toString();
                 }
                 else
                 {
-                    return _ComponentUtils.UNIQUE_COMPONENT_RD_IDS[uniqueIdCounter];
+                    return ComponentUtils.UNIQUE_COMPONENT_RD_IDS[uniqueIdCounter];
                 }
             }
             else
@@ -498,15 +505,14 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
                 Integer uniqueIdCounter = (Integer) getStateHelper().get(PropertyKeys.uniqueIdCounter);
                 uniqueIdCounter = (uniqueIdCounter == null) ? 0 : uniqueIdCounter;
                 getStateHelper().put(PropertyKeys.uniqueIdCounter, (uniqueIdCounter+1));
-                if (uniqueIdCounter >= _ComponentUtils.UNIQUE_COMPONENT_V_IDS_SIZE)
+                if (uniqueIdCounter >= ComponentUtils.UNIQUE_COMPONENT_V_IDS_SIZE)
                 {
                     StringBuilder bld = _getSharedStringBuilder(context);
-                    return bld.append(UNIQUE_ID_PREFIX).append(
-                        _ComponentUtils.V_ID_PREFIX).append(uniqueIdCounter).toString();
+                    return bld.append(UNIQUE_ID_PREFIX).append(ComponentUtils.V_ID_PREFIX).append(uniqueIdCounter).toString();
                 }
                 else
                 {
-                    return _ComponentUtils.UNIQUE_COMPONENT_V_IDS[uniqueIdCounter];
+                    return ComponentUtils.UNIQUE_COMPONENT_V_IDS[uniqueIdCounter];
                 }
             }
         }
@@ -522,7 +528,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
     @Override
     public void encodeBegin(FacesContext context) throws IOException
     {
-        checkNull(context, "context");
+        Assert.notNull(context, "context");
 
         boolean skipPhase = false;
 
@@ -581,7 +587,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
     @Override
     public void encodeEnd(FacesContext context) throws IOException
     {
-        checkNull(context, "context");
+        Assert.notNull(context, "context");
 
         if (!context.getResponseComplete())
         {
@@ -648,26 +654,24 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
     }
 
     /**
-     * MethodBinding pointing to a method that takes a jakarta.faces.event.PhaseEvent and returns void, called after every
-     * phase except for restore view.
+     * MethodExpression pointing to a method that takes a jakarta.faces.event.PhaseEvent and returns void,
+     * called after every phase except for restore view.
      *
      * @return the new afterPhaseListener value
      */
-    @JSFProperty(returnSignature = "void", methodSignature = "jakarta.faces.event.PhaseEvent",
-                 jspName = "afterPhase", stateHolder=true)
+    @JSFProperty(returnSignature = "void", methodSignature = "jakarta.faces.event.PhaseEvent", stateHolder=true)
     public MethodExpression getAfterPhaseListener()
     {
         return (MethodExpression) getStateHelper().eval(PropertyKeys.afterPhaseListener);
     }
 
     /**
-     * MethodBinding pointing to a method that takes a jakarta.faces.event.PhaseEvent and returns void, called before
-     * every phase except for restore view.
+     * MethodExpression pointing to a method that takes a jakarta.faces.event.PhaseEvent and returns void,
+     * called before every phase except for restore view.
      *
      * @return the new beforePhaseListener value
      */
-    @JSFProperty(returnSignature = "void", methodSignature = "jakarta.faces.event.PhaseEvent",
-                 jspName = "beforePhase", stateHolder=true)
+    @JSFProperty(returnSignature = "void", methodSignature = "jakarta.faces.event.PhaseEvent", stateHolder=true)
     public MethodExpression getBeforePhaseListener()
     {
         return (MethodExpression) getStateHelper().eval(PropertyKeys.beforePhaseListener);
@@ -678,10 +682,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
      */
     public List<UIComponent> getComponentResources(FacesContext context, String target)
     {
-        if (target == null)
-        {
-            throw new NullPointerException("target");
-        }
+        Assert.notNull(target, "target");
         // Locate the facet for the component by calling getFacet() using target as the argument
         UIComponent facet = getFacet(target);
 
@@ -715,10 +716,10 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
             }
             else
             {
-                return Collections.<UIComponent>emptyList();
+                return Collections.emptyList();
             }
         }
-        return Collections.<UIComponent>emptyList();
+        return Collections.emptyList();
     }
     
     private List<UIComponent> _getComponentResources(FacesContext context, String target)
@@ -732,7 +733,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
             // create the facet by calling context.getApplication().createComponent()
             // using jakarta.faces.Panel as the argument
             facet = context.getApplication().createComponent(context,
-                "jakarta.faces.componentResourceContainer", null);
+                "jakarta.faces.ComponentResourceContainer", null);
 
             // Set the id of the facet to be target
             if (target.equals("head"))
@@ -813,7 +814,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
             }
             else
             {
-                return (Locale) _LocaleUtils.toLocale(veLocale.toString());
+                return LocaleUtils.toLocale(veLocale.toString());
             }
         }
         else
@@ -826,7 +827,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
             }
             else if (locale instanceof String)
             {
-                return _LocaleUtils.toLocale((String)locale);
+                return LocaleUtils.toLocale((String)locale);
             }
         }
 
@@ -900,16 +901,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
     {
         if (_viewScope == null && create)
         {
-            if (VIEW_SCOPE_PROXY_MAP_CLASS != null)
-            {
-                _viewScope = (Map<String, Object>)
-                    _ClassUtils.newInstance(VIEW_SCOPE_PROXY_MAP_CLASS);
-            }
-            else
-            {
-                //Default to map for testing purposes
-                _viewScope = new ViewScope();
-            }
+            _viewScope = (Map<String, Object>) ClassUtils.newInstance(VIEW_SCOPE_PROXY_MAP_CLASS);
             FacesContext facesContext = getFacesContext();
             if (facesContext != null)
             {
@@ -931,14 +923,14 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
 
     public void processApplication(final FacesContext context)
     {
-        checkNull(context, "context");
+        Assert.notNull(context, "context");
         _process(context, PhaseId.INVOKE_APPLICATION, null);
     }
 
     @Override
     public void processDecodes(FacesContext context)
     {
-        checkNull(context, "context");
+        Assert.notNull(context, "context");
         _process(context, PhaseId.APPLY_REQUEST_VALUES, APPLY_REQUEST_VALUES_PROCESSOR);
     }
 
@@ -958,15 +950,13 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         {
             // The try block must have a finally block that ensures that no FacesEvents remain in the event queue
             broadcastEvents(context, PhaseId.RESTORE_VIEW);
-
-            //visitTree(VisitContext.createVisitContext(context), new RestoreStateCallback());
         }
     }
 
     @Override
     public void queueEvent(FacesEvent event)
     {
-        checkNull(event, "event");
+        Assert.notNull(event, "event");
         if (_events == null)
         {
             _events = new ArrayList<FacesEvent>();
@@ -978,26 +968,26 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
     @Override
     public void processValidators(FacesContext context)
     {
-        checkNull(context, "context");
+        Assert.notNull(context, "context");
         _process(context, PhaseId.PROCESS_VALIDATIONS, PROCESS_VALIDATORS_PROCESSOR);
     }
 
     @Override
     public void processUpdates(FacesContext context)
     {
-        checkNull(context, "context");
+        Assert.notNull(context, "context");
         _process(context, PhaseId.UPDATE_MODEL_VALUES, UPDATE_MODEL_PROCESSOR);
     }
 
     public void setLocale(Locale locale)
     {
-        getStateHelper().put(PropertyKeys.locale, locale );
+        getStateHelper().put(PropertyKeys.locale, locale);
     }
 
     /**
      * Invoke view-specific phase listeners, plus an optional EL MethodExpression.
      * <p>
-     * JSF1.2 adds the ability for PhaseListener objects to be added to a UIViewRoot instance, and for
+     * Faces1.2 adds the ability for PhaseListener objects to be added to a UIViewRoot instance, and for
      * "beforePhaseListener" and "afterPhaseListener" EL expressions to be defined on the viewroot. This method is
      * expected to be called at appropriate times, and will then execute the relevant listener callbacks.
      * <p>
@@ -1204,7 +1194,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
     {
         if (_lifecycle == null)
         {
-            LifecycleFactory factory = (LifecycleFactory) FactoryFinder.getFactory(FactoryFinder.LIFECYCLE_FACTORY);
+            LifecycleFactory factory = (LifecycleFactory)FactoryFinder.getFactory(FactoryFinder.LIFECYCLE_FACTORY);
             String id = context.getExternalContext().getInitParameter(FacesServlet.LIFECYCLE_ID_ATTR);
             if (id == null)
             {
@@ -1219,7 +1209,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
      * Broadcast all events in the specified collection, stopping the at any time an AbortProcessingException
      * is thrown.
      *
-     * @param context the current JSF context
+     * @param context the current Faces context
      * @param events the events to broadcast
      * @return 
      *
@@ -1236,7 +1226,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         {
             FacesEvent event = events.get(i);
             UIComponent source = event.getComponent();
-            UIComponent compositeParent = getCompositeComponentParent(source);
+            UIComponent compositeParent = UIComponent.getCompositeComponentParent(source);
             if (compositeParent != null)
             {
                 pushComponentToEL(context, compositeParent);
@@ -1322,14 +1312,6 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         _events = null;
     }
 
-    private void checkNull(Object value, String valueLabel)
-    {
-        if (value == null)
-        {
-            throw new NullPointerException(valueLabel + " is null");
-        }
-    }
-
     public void setRenderKitId(String renderKitId)
     {
         getStateHelper().put(PropertyKeys.renderKitId, renderKitId );
@@ -1340,7 +1322,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
      * <p>
      * This inherited property is disabled. Although this class extends a base-class that defines a read/write rendered
      * property, this particular subclass does not support setting it. Yes, this is broken OO design: direct all
-     * complaints to the JSF spec group.
+     * complaints to the Faces spec group.
      */
     @Override
     @JSFProperty(tagExcluded = true)
@@ -1476,12 +1458,10 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
      * @param context
      * @param clientIds 
      */
-    public void resetValues(FacesContext context,
-                        java.util.Collection<java.lang.String> clientIds)    
+    public void resetValues(FacesContext context, java.util.Collection<java.lang.String> clientIds)    
     {
-        VisitContext visitContext = (VisitContext) VisitContext.createVisitContext(
-            context, clientIds, null);
-        this.visitTree(visitContext, RESET_VALUES_CALLBACK);
+        VisitContext visitContext = VisitContext.createVisitContext(context, clientIds, null);
+        this.visitTree(visitContext, ResetValuesCallback.INSTANCE);
     }
 
     /**
@@ -1618,8 +1598,8 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         
         Object[] values = (Object[])state;
         super.restoreState(facesContext,values[0]);
-        // JSF 2.2 spec says that restoreViewScopeState can be called but only if
-        // StateManagementStrategy is used. If that's not the case (JSF 1.2 state saving),
+        // Faces 2.2 spec says that restoreViewScopeState can be called but only if
+        // StateManagementStrategy is used. If that's not the case (Faces 1.2 state saving),
         // restoreViewScopeState could not be called, so this code should avoid restore
         // the state twice.
         if (!_restoreViewScopeStateCalled)
@@ -1658,57 +1638,53 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
     
     public List<SystemEventListener> getViewListenersForEventClass(Class<? extends SystemEvent> systemEvent)
     {
-        checkNull (systemEvent, "systemEvent");
+        Assert.notNull(systemEvent, "systemEvent");
         if (_systemEventListeners == null)
         {
             return null;
         }
-        return _systemEventListeners.get (systemEvent);
+        return _systemEventListeners.get(systemEvent);
     }
     
-    public void subscribeToViewEvent(Class<? extends SystemEvent> systemEvent,
-            SystemEventListener listener)
+    public void subscribeToViewEvent(Class<? extends SystemEvent> systemEvent, SystemEventListener listener)
     {
         List<SystemEventListener> listeners;
         
-        checkNull (systemEvent, "systemEvent");
-        checkNull (listener, "listener");
+        Assert.notNull(systemEvent, "systemEvent");
+        Assert.notNull(listener, "listener");
         
         if (_systemEventListeners == null)
         {
-            _systemEventListeners = new HashMap<Class<? extends SystemEvent>, List<SystemEventListener>>();
+            _systemEventListeners = new HashMap<>(4, 1f);
         }
         
-        listeners = _systemEventListeners.get (systemEvent);
-        
+        listeners = _systemEventListeners.get(systemEvent);
         if (listeners == null)
         {
             listeners = new ArrayList<SystemEventListener>();
             
-            _systemEventListeners.put (systemEvent, listeners);
+            _systemEventListeners.put(systemEvent, listeners);
         }
         
         listeners.add (listener);
     }
     
-    public void unsubscribeFromViewEvent(Class<? extends SystemEvent> systemEvent,
-            SystemEventListener listener)
+    public void unsubscribeFromViewEvent(Class<? extends SystemEvent> systemEvent, SystemEventListener listener)
     {
         List<SystemEventListener> listeners;
         
-        checkNull (systemEvent, "systemEvent");
-        checkNull (listener, "listener");
+        Assert.notNull (systemEvent, "systemEvent");
+        Assert.notNull (listener, "listener");
         
         if (_systemEventListeners == null)
         {
             return;
         }
         
-        listeners = _systemEventListeners.get (systemEvent);
-        
+        listeners = _systemEventListeners.get(systemEvent);
         if (listeners != null)
         {
-            listeners.remove (listener);
+            listeners.remove(listener);
         }
     }
 
@@ -1790,8 +1766,8 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
     {
         // Gather the events and purge the event list to prevent concurrent modification during broadcasting
         int size = _events.size();
-        List<FacesEvent> anyPhase = new ArrayList<FacesEvent>(size);
-        List<FacesEvent> onPhase = new ArrayList<FacesEvent>(size);
+        List<FacesEvent> anyPhase = new ArrayList<>(size);
+        List<FacesEvent> onPhase = new ArrayList<>(size);
         
         for (int i = 0; i < size; i++)
         {
@@ -1826,10 +1802,9 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
 
     private Map<PhaseId, boolean[]> _getListenerSuccessMap()
     {
-        // lazy init: 
         if (listenerSuccessMap == null)
         {
-            listenerSuccessMap = new HashMap<PhaseId, boolean[]>();
+            listenerSuccessMap = new HashMap<>(PhaseId.VALUES.size(), 1f);
         }
         return listenerSuccessMap;
     }
@@ -1841,6 +1816,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
 
     private static class ApplyRequestValuesPhaseProcessor implements PhaseProcessor
     {
+        @Override
         public void process(FacesContext context, UIViewRoot root)
         {
             PartialViewContext pvc = context.getPartialViewContext();
@@ -1848,7 +1824,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
             // with PhaseId.UPDATE_MODEL_VALUES if:
             //   * PartialViewContext.isPartialRequest() returns true and we don't have a request to process all
             // components in the view (PartialViewContext.isExecuteAll() returns false)
-            //section 13.4.2 from the  JSF2  spec also see https://issues.apache.org/jira/browse/MYFACES-2119
+            //section 13.4.2 from the  Faces2  spec also see https://issues.apache.org/jira/browse/MYFACES-2119
             if (pvc.isPartialRequest() && !pvc.isExecuteAll())
             {
                 pvc.processPartial(PhaseId.APPLY_REQUEST_VALUES);
@@ -1867,6 +1843,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
 
     private static class ProcessValidatorPhaseProcessor implements PhaseProcessor
     {
+        @Override
         public void process(FacesContext context, UIViewRoot root)
         {
             PartialViewContext pvc = context.getPartialViewContext();
@@ -1874,7 +1851,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
             // with PhaseId.UPDATE_MODEL_VALUES if:
             // PartialViewContext.isPartialRequest() returns true and we don't have a request to process all components
             // in the view (PartialViewContext.isExecuteAll() returns false)
-            //section 13.4.2 from the  JSF2  spec also see https://issues.apache.org/jira/browse/MYFACES-2119
+            //section 13.4.2 from the  Faces2  spec also see https://issues.apache.org/jira/browse/MYFACES-2119
             if (pvc.isPartialRequest() && !pvc.isExecuteAll())
             {
                 pvc.processPartial(PhaseId.PROCESS_VALIDATIONS);
@@ -1893,6 +1870,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
 
     private static class UpdateModelPhaseProcessor implements PhaseProcessor
     {
+        @Override
         public void process(FacesContext context, UIViewRoot root)
         {
             PartialViewContext pvc = context.getPartialViewContext();
@@ -1900,7 +1878,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
             // with PhaseId.UPDATE_MODEL_VALUES if:
             //   * PartialViewContext.isPartialRequest() returns true and we don't have a request to process
             // all components in the view (PartialViewContext.isExecuteAll() returns false)
-            //section 13.4.2 from the JSF2 spec also see https://issues.apache.org/jira/browse/MYFACES-2119
+            //section 13.4.2 from the Faces2 spec also see https://issues.apache.org/jira/browse/MYFACES-2119
             if (pvc.isPartialRequest() && !pvc.isExecuteAll())
             {
                 pvc.processPartial(PhaseId.UPDATE_MODEL_VALUES);
@@ -1917,68 +1895,12 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         }
     }
 
-/*
-    private static class RestoreStateCallback implements VisitCallback
-    {
-        private PostRestoreStateEvent event;
-
-        public VisitResult visit(VisitContext context, UIComponent target)
-        {
-            if (event == null)
-            {
-                event = new PostRestoreStateEvent(target);
-            }
-            else
-            {
-                event.setComponent(target);
-            }
-
-            // call the processEvent method of the current component.
-            // The argument event must be an instance of AfterRestoreStateEvent whose component
-            // property is the current component in the traversal.
-            target.processEvent(event);
-            
-            return VisitResult.ACCEPT;
-        }
-    }
-*/
-
-    // we cannot make this class a inner class, because the 
-    // enclosing class (UIViewRoot) would also have to be serialized.
-    /**
-     * @deprecated replaced by org.apache.myfaces.view.ViewScopeProxyMap
-     */
-    @Deprecated
-    private static class ViewScope extends HashMap<String, Object>
-    {
-        
-        private static final long serialVersionUID = -1088893802269478164L;
-        
-        @Override
-        public void clear()
-        {
-            /*
-             * The returned Map must be implemented such that calling clear() on the Map causes
-             * Application.publishEvent(java.lang.Class, java.lang.Object) to be called, passing
-             * ViewMapDestroyedEvent.class as the first argument and this UIViewRoot instance as the second argument.
-             */
-            FacesContext facesContext = FacesContext.getCurrentInstance();
-            facesContext.getApplication().publishEvent(facesContext, 
-                    PreDestroyViewMapEvent.class, facesContext.getViewRoot());
-            
-            super.clear();
-        }
-        
-    }
-
     /**
      * Agregates events for ANY_PHASE and current phase 
      */
     private static class Events
     {
-        
         private final List<FacesEvent> _anyPhase;
-        
         private final List<FacesEvent> _onPhase;
         
         public Events(List<FacesEvent> anyPhase, List<FacesEvent> onPhase)
@@ -2006,6 +1928,9 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
     
     private static class ResetValuesCallback implements VisitCallback
     {
+        private static final ResetValuesCallback INSTANCE = new ResetValuesCallback();
+        
+        @Override
         public VisitResult visit(VisitContext context, UIComponent target)
         {
             if (target instanceof EditableValueHolder)
@@ -2016,7 +1941,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         }
     }
     
-    private void publishException (FacesContext facesContext, Throwable e, PhaseId phaseId, String key)
+    private void publishException(FacesContext facesContext, Throwable e, PhaseId phaseId, String key)
     {
         ExceptionQueuedEventContext context = new ExceptionQueuedEventContext (facesContext, e, null, phaseId);
         
@@ -2062,4 +1987,28 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
 
         return alwaysPerformValidationWhenRequiredTrue;
     }    
+
+    /**
+     * <p>
+     * Return the doctype of this view.
+     * </p>
+     *
+     * @return the doctype of this view.
+     * @since 4.0
+     */
+    public Doctype getDoctype() {
+        return doctype;
+    }
+
+    /**
+     * <p>
+     * Set the doctype of this view.
+     * </p>
+     *
+     * @param doctype The doctype.
+     * @since 4.0
+     */
+    public void setDoctype(Doctype doctype) {
+        this.doctype = doctype;
+    }
 }
