@@ -19,9 +19,9 @@ import java.io.Serializable;
 import jakarta.faces.context.FacesContext;
 import jakarta.faces.convert.Converter;
 import jakarta.faces.convert.LongConverter;
-import junit.framework.Assert;
-import org.apache.myfaces.test.base.junit4.AbstractJsfTestCase;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.apache.myfaces.test.base.junit.AbstractJsfTestCase;
+import org.junit.jupiter.api.Test;
 
 public class UIOutputPSSTest extends AbstractJsfTestCase
 {
@@ -42,7 +42,7 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         Object state1 = output.saveState(facesContext);
         
         // null delta expected
-        Assert.assertNull(state1);
+        Assertions.assertNull(state1);
         
         UIOutput output2 = new UIOutput();
         output2.setId("output1");
@@ -53,7 +53,7 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         output2.restoreState(facesContext, state1);
         
         // Check converter is not replaced, because it is not necessary
-        Assert.assertEquals(converter2, output2.getConverter());
+        Assertions.assertEquals(converter2, output2.getConverter());
     }
     
     @Test
@@ -67,7 +67,7 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         Object state1 = output.saveState(facesContext);
         
         // null delta expected
-        Assert.assertNull(state1);
+        Assertions.assertNull(state1);
         
         UIOutput output2 = new UIOutput();
         output2.setId("output1");
@@ -78,7 +78,7 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         output2.restoreState(facesContext, state1);
         
         // Check converter is not replaced, because it is not necessary
-        Assert.assertEquals(converter2, output2.getConverter());
+        Assertions.assertEquals(converter2, output2.getConverter());
     }
     
     @Test
@@ -92,7 +92,7 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         Object state1 = output.saveState(facesContext);
         
         // StateHolder only force always to save the state
-        Assert.assertNotNull(state1);
+        Assertions.assertNotNull(state1);
         
         UIOutput output2 = new UIOutput();
         output2.setId("output1");
@@ -103,7 +103,7 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         output2.restoreState(facesContext, state1);
         
         // Check converter IS replaced, because it should be always stored into the state
-        Assert.assertNotSame(converter2, output2.getConverter());
+        Assertions.assertNotSame(converter2, output2.getConverter());
     }
     
     @Test
@@ -117,7 +117,7 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         Object state1 = output.saveState(facesContext);
         
         // PartialStateHolder only save state if delta is null
-        Assert.assertNull(state1);
+        Assertions.assertNull(state1);
         
         UIOutput output2 = new UIOutput();
         output2.setId("output1");
@@ -128,7 +128,7 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         output2.restoreState(facesContext, state1);
         
         // Check converter is not replaced, because it is not necessary
-        Assert.assertEquals(converter2, output2.getConverter());
+        Assertions.assertEquals(converter2, output2.getConverter());
     }
     
     @Test
@@ -142,7 +142,7 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         Object state1 = output.saveState(facesContext);
         
         // PartialStateHolder only save state if delta is null
-        Assert.assertNotNull(state1);
+        Assertions.assertNotNull(state1);
         
         UIOutput output2 = new UIOutput();
         output2.setId("output1");
@@ -153,7 +153,7 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         output2.restoreState(facesContext, state1);
         
         // Check converter is not replaced, because it is not necessary (delta change)
-        Assert.assertEquals(converter2, output2.getConverter());
+        Assertions.assertEquals(converter2, output2.getConverter());
     }
     
     @Test
@@ -170,8 +170,8 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         Object[] state1 = (Object[])output.saveState(facesContext);
         
         // null delta expected
-        Assert.assertNotNull(state1);
-        Assert.assertEquals(state1.length, 1);
+        Assertions.assertNotNull(state1);
+        Assertions.assertEquals(state1.length, 1);
         
         UIOutput output2 = new UIOutput();
         output2.setId("output1");
@@ -182,10 +182,10 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         output2.restoreState(facesContext, state1);
         
         // Check converter is not replaced, because it is not necessary
-        Assert.assertEquals(converter2, output2.getConverter());
+        Assertions.assertEquals(converter2, output2.getConverter());
         
         // Check parentDelta works
-        Assert.assertEquals("style1", output2.getAttributes().get("style"));
+        Assertions.assertEquals("style1", output2.getAttributes().get("style"));
     }
 
     @Test
@@ -202,8 +202,8 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         Object[] state1 = (Object[])output.saveState(facesContext);
         
         // null delta expected
-        Assert.assertNotNull(state1);
-        Assert.assertEquals(state1.length, 1);
+        Assertions.assertNotNull(state1);
+        Assertions.assertEquals(state1.length, 1);
         
         UIOutput output2 = new UIOutput();
         output2.setId("output1");
@@ -214,10 +214,10 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         output2.restoreState(facesContext, state1);
         
         // Check converter is not replaced, because it is not necessary
-        Assert.assertEquals(converter2, output2.getConverter());
+        Assertions.assertEquals(converter2, output2.getConverter());
         
         // Check parentDelta works
-        Assert.assertEquals("style1", output2.getAttributes().get("style"));
+        Assertions.assertEquals("style1", output2.getAttributes().get("style"));
     }
     
     @Test
@@ -234,10 +234,10 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         Object[] state1 = (Object[])output.saveState(facesContext);
         
         // StateHolder force state
-        Assert.assertNotNull(state1);
-        Assert.assertEquals(state1.length, 2);
-        Assert.assertNotNull(state1[1]);
-        Assert.assertNotNull(state1[0]);
+        Assertions.assertNotNull(state1);
+        Assertions.assertEquals(state1.length, 2);
+        Assertions.assertNotNull(state1[1]);
+        Assertions.assertNotNull(state1[0]);
         
         UIOutput output2 = new UIOutput();
         output2.setId("output1");
@@ -248,10 +248,10 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         output2.restoreState(facesContext, state1);
         
         // Check converter IS replaced, because it should be always stored into the state
-        Assert.assertNotSame(converter2, output2.getConverter());
+        Assertions.assertNotSame(converter2, output2.getConverter());
         
         // Check parentDelta works
-        Assert.assertEquals("style1", output2.getAttributes().get("style"));
+        Assertions.assertEquals("style1", output2.getAttributes().get("style"));
     }
 
     @Test
@@ -268,8 +268,8 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         Object[] state1 = (Object[])output.saveState(facesContext);
         
         // null delta expected
-        Assert.assertNotNull(state1);
-        Assert.assertEquals(state1.length, 1);
+        Assertions.assertNotNull(state1);
+        Assertions.assertEquals(state1.length, 1);
         
         UIOutput output2 = new UIOutput();
         output2.setId("output1");
@@ -280,10 +280,10 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         output2.restoreState(facesContext, state1);
         
         // Check converter is not replaced, because it is not necessary
-        Assert.assertEquals(converter2, output2.getConverter());
+        Assertions.assertEquals(converter2, output2.getConverter());
         
         // Check parentDelta works
-        Assert.assertEquals("style1", output2.getAttributes().get("style"));
+        Assertions.assertEquals("style1", output2.getAttributes().get("style"));
     }
     
     @Test
@@ -300,10 +300,10 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         Object[] state1 = (Object[])output.saveState(facesContext);
         
         // PartialStateHolder force state only when there is delta
-        Assert.assertNotNull(state1);
-        Assert.assertEquals(state1.length, 2);
-        Assert.assertNotNull(state1[1]);
-        Assert.assertNotNull(state1[0]);
+        Assertions.assertNotNull(state1);
+        Assertions.assertEquals(state1.length, 2);
+        Assertions.assertNotNull(state1[1]);
+        Assertions.assertNotNull(state1[0]);
         
         UIOutput output2 = new UIOutput();
         output2.setId("output1");
@@ -314,10 +314,10 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         output2.restoreState(facesContext, state1);
         
         // Check converter is not replaced, because it is not necessary (delta change)
-        Assert.assertEquals(converter2, output2.getConverter());
+        Assertions.assertEquals(converter2, output2.getConverter());
         
         // Check parentDelta works
-        Assert.assertEquals("style1", output2.getAttributes().get("style"));
+        Assertions.assertEquals("style1", output2.getAttributes().get("style"));
     }
     
     /**
@@ -354,10 +354,10 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
             Object[] state1 = (Object[])output.saveState(facesContext);
 
             // The null spot force state to be set.
-            Assert.assertNotNull(state1);
-            Assert.assertEquals(state1.length, 2);
-            Assert.assertNull(state1[1]); // null spot in state means null Converter
-            Assert.assertNotNull(state1[0]); //because _isConverterSet()
+            Assertions.assertNotNull(state1);
+            Assertions.assertEquals(state1.length, 2);
+            Assertions.assertNull(state1[1]); // null spot in state means null Converter
+            Assertions.assertNotNull(state1[0]); //because _isConverterSet()
 
             UIOutput output2 = new UIOutput();
             output2.setId("output1");
@@ -368,7 +368,7 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
             output2.restoreState(facesContext, state1);
 
             // Check converter is set to null
-            Assert.assertNull(output2.getConverter());
+            Assertions.assertNull(output2.getConverter());
         }
     }
 
@@ -383,8 +383,8 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         Object state1 = output.saveState(facesContext);
         
         // Transient means no state, but the effect is the converter dissapear
-        // (because is transient, and in JSF 1.2/1.1 that was the effect).
-        Assert.assertNotNull(state1);
+        // (because is transient, and in Faces 1.2/1.1 that was the effect).
+        Assertions.assertNotNull(state1);
         
         UIOutput output2 = new UIOutput();
         output2.setId("output1");
@@ -395,7 +395,7 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         output2.restoreState(facesContext, state1);
         
         // Check no converter should be found
-        Assert.assertNull(output2.getConverter());
+        Assertions.assertNull(output2.getConverter());
     }
     
     @Test
@@ -409,8 +409,8 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         Object state1 = output.saveState(facesContext);
         
         // Transient means no state, but the effect is the converter dissapear
-        // (because is transient, and in JSF 1.2/1.1 that was the effect).
-        Assert.assertNotNull(state1);
+        // (because is transient, and in Faces 1.2/1.1 that was the effect).
+        Assertions.assertNotNull(state1);
         
         UIOutput output2 = new UIOutput();
         output2.setId("output1");
@@ -421,7 +421,7 @@ public class UIOutputPSSTest extends AbstractJsfTestCase
         output2.restoreState(facesContext, state1);
         
         // Check no converter should be found
-        Assert.assertNull(output2.getConverter());
+        Assertions.assertNull(output2.getConverter());
     }
 
     public static class LongSerializableConverter extends LongConverter implements Serializable
